==> lambdas3-1.81.0-sources.jar: software/amazon/awsconstructs/services/lambdas3/LambdaToS3.java <==
package software.amazon.awsconstructs.services.lambdas3;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.17.1 (build 2bac5fd)", date = "2021-01-14T19:02:32.414Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdas3.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-s3.LambdaToS3")
public class LambdaToS3 extends software.amazon.awscdk.core.Construct {

    protected LambdaToS3(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToS3(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public LambdaToS3(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdas3.LambdaToS3Props props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3Bucket() {
        return software.amazon.jsii.Kernel.get(this, "s3Bucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3LoggingBucket() {
        return software.amazon.jsii.Kernel.get(this, "s3LoggingBucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdas3.LambdaToS3}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdas3.LambdaToS3> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdas3.LambdaToS3Props.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdas3.LambdaToS3Props.Builder();
        }

        /**
         * Optional bucket permissions to grant to the Lambda function.
         * <p>
         * One or more of the following may be specified: "Delete", "Put", "Read", "ReadWrite", "Write".
         * <p>
         * Default: - Read/write access is given to the Lambda function if no value is specified.
         * <p>
         * @return {@code this}
         * @param bucketPermissions Optional bucket permissions to grant to the Lambda function. This parameter is required.
         */
        public Builder bucketPermissions(final java.util.List<java.lang.String> bucketPermissions) {
            this.props.bucketPermissions(bucketPermissions);
            return this;
        }

        /**
         * User provided props to override the default props for the S3 Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param bucketProps User provided props to override the default props for the S3 Bucket. This parameter is required.
         */
        public Builder bucketProps(final software.amazon.awscdk.services.s3.BucketProps bucketProps) {
            this.props.bucketProps(bucketProps);
            return this;
        }

        /**
         * Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingBucketObj Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored. This parameter is required.
         */
        public Builder existingBucketObj(final software.amazon.awscdk.services.s3.IBucket existingBucketObj) {
            this.props.existingBucketObj(existingBucketObj);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.lambdas3.LambdaToS3}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdas3.LambdaToS3 build() {
            return new software.amazon.awsconstructs.services.lambdas3.LambdaToS3(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> lambdas3-1.90.0-sources.jar: software/amazon/awsconstructs/services/lambdas3/LambdaToS3.java <==
package software.amazon.awsconstructs.services.lambdas3;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.23.0 (build 7aea3d1)", date = "2021-03-02T15:37:07.172Z")
@software.amazon.jsii.Jsii(module = software.amazon.awsconstructs.services.lambdas3.$Module.class, fqn = "@aws-solutions-constructs/aws-lambda-s3.LambdaToS3")
public class LambdaToS3 extends software.amazon.awscdk.core.Construct {

    protected LambdaToS3(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected LambdaToS3(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope - represents the scope for all the resources. This parameter is required.
     * @param id - this is a a scope-unique id. This parameter is required.
     * @param props - user provided props for the construct. This parameter is required.
     */
    public LambdaToS3(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.core.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awsconstructs.services.lambdas3.LambdaToS3Props props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    public @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.lambda.Function getLambdaFunction() {
        return software.amazon.jsii.Kernel.get(this, "lambdaFunction", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.lambda.Function.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3Bucket() {
        return software.amazon.jsii.Kernel.get(this, "s3Bucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.s3.Bucket getS3LoggingBucket() {
        return software.amazon.jsii.Kernel.get(this, "s3LoggingBucket", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.s3.Bucket.class));
    }

    public @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.ec2.IVpc getVpc() {
        return software.amazon.jsii.Kernel.get(this, "vpc", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.ec2.IVpc.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awsconstructs.services.lambdas3.LambdaToS3}.
     */
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awsconstructs.services.lambdas3.LambdaToS3> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope - represents the scope for all the resources. This parameter is required.
         * @param id - this is a a scope-unique id. This parameter is required.
         */
        public static Builder create(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.amazon.awscdk.core.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awsconstructs.services.lambdas3.LambdaToS3Props.Builder props;

        private Builder(final software.amazon.awscdk.core.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awsconstructs.services.lambdas3.LambdaToS3Props.Builder();
        }

        /**
         * Optional bucket permissions to grant to the Lambda function.
         * <p>
         * One or more of the following may be specified: "Delete", "Put", "Read", "ReadWrite", "Write".
         * <p>
         * Default: - Read/write access is given to the Lambda function if no value is specified.
         * <p>
         * @return {@code this}
         * @param bucketPermissions Optional bucket permissions to grant to the Lambda function. This parameter is required.
         */
        public Builder bucketPermissions(final java.util.List<java.lang.String> bucketPermissions) {
            this.props.bucketPermissions(bucketPermissions);
            return this;
        }

        /**
         * User provided props to override the default props for the S3 Bucket.
         * <p>
         * Default: - Default props are used
         * <p>
         * @return {@code this}
         * @param bucketProps User provided props to override the default props for the S3 Bucket. This parameter is required.
         */
        public Builder bucketProps(final software.amazon.awscdk.services.s3.BucketProps bucketProps) {
            this.props.bucketProps(bucketProps);
            return this;
        }

        /**
         * Whether to deploy a new VPC.
         * <p>
         * Default: - false
         * <p>
         * @return {@code this}
         * @param deployVpc Whether to deploy a new VPC. This parameter is required.
         */
        public Builder deployVpc(final java.lang.Boolean deployVpc) {
            this.props.deployVpc(deployVpc);
            return this;
        }

        /**
         * Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingBucketObj Existing instance of S3 Bucket object, if this is set then the bucketProps is ignored. This parameter is required.
         */
        public Builder existingBucketObj(final software.amazon.awscdk.services.s3.IBucket existingBucketObj) {
            this.props.existingBucketObj(existingBucketObj);
            return this;
        }

        /**
         * Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
         * <p>
         * Default: - None
         * <p>
         * @return {@code this}
         * @param existingLambdaObj Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. This parameter is required.
         */
        public Builder existingLambdaObj(final software.amazon.awscdk.services.lambda.Function existingLambdaObj) {
            this.props.existingLambdaObj(existingLambdaObj);
            return this;
        }

        /**
         * An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         * <p>
         * @return {@code this}
         * @param existingVpc An existing VPC for the construct to use (construct will NOT create a new VPC in this case). This parameter is required.
         */
        public Builder existingVpc(final software.amazon.awscdk.services.ec2.IVpc existingVpc) {
            this.props.existingVpc(existingVpc);
            return this;
        }

        /**
         * User provided props to override the default props for the Lambda function.
         * <p>
         * Default: - Default properties are used.
         * <p>
         * @return {@code this}
         * @param lambdaFunctionProps User provided props to override the default props for the Lambda function. This parameter is required.
         */
        public Builder lambdaFunctionProps(final software.amazon.awscdk.services.lambda.FunctionProps lambdaFunctionProps) {
            this.props.lambdaFunctionProps(lambdaFunctionProps);
            return this;
        }

        /**
         * Properties to override default properties if deployVpc is true.
         * <p>
         * @return {@code this}
         * @param vpcProps Properties to override default properties if deployVpc is true. This parameter is required.
         */
        public Builder vpcProps(final software.amazon.awscdk.services.ec2.VpcProps vpcProps) {
            this.props.vpcProps(vpcProps);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awsconstructs.services.lambdas3.LambdaToS3}.
         */
        @Override
        public software.amazon.awsconstructs.services.lambdas3.LambdaToS3 build() {
            return new software.amazon.awsconstructs.services.lambdas3.LambdaToS3(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
